function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/*
Copyright (c) Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import React, { isValidElement } from 'react';
import { useStyletron } from '../styles/index';
import { getOverrides } from '../helpers/overrides';
import { ButtonDock } from '../button-dock';
import { Button, KIND, SHAPE } from '../button';
import { Delete } from '../icon';
import { StyledHeading, StyledBody, StyledRoot, StyledScrollContainer } from './styled-components';
import { PLACEMENT, SIZE } from './constants';

function renderArtwork(artwork) {
  if ( /*#__PURE__*/isValidElement(artwork)) {
    return artwork;
  } else if (typeof artwork === 'function') {
    const ArtworkComponent = artwork;
    return /*#__PURE__*/React.createElement(ArtworkComponent, null);
  }

  return null;
}

const DefaultDismissButton = props => {
  const overrides = {
    BaseButton: {
      style: {
        position: 'absolute',
        top: '16px',
        right: '8px',
        // this will be tokenized in the future
        backgroundColor: 'rgba(255, 255, 255, 0.6)',
        zIndex: 1
      }
    }
  };
  return /*#__PURE__*/React.createElement(Button, _extends({
    kind: KIND.secondary,
    shape: SHAPE.circle,
    overrides: overrides
  }, props), /*#__PURE__*/React.createElement(Delete, {
    size: 36
  }));
};

const DefaultButtonDock = props => {
  const [, theme] = useStyletron();
  const overrides = {
    Root: {
      style: {
        paddingRight: theme.sizing.scale800,
        paddingLeft: theme.sizing.scale800,
        marginBottom: theme.sizing.scale800
      }
    }
  };
  return /*#__PURE__*/React.createElement(ButtonDock, _extends({
    overrides: overrides
  }, props));
};

const Dialog = ({
  artwork,
  buttonDock,
  children,
  handleDismiss,
  showDismissButton = true,
  hasOverlay = true,
  heading,
  isOpen,
  overrides = {},
  placement = PLACEMENT.center,
  numHeadingLines = 2,
  size = SIZE.xSmall
}) => {
  const [Root, rootProps] = getOverrides(overrides.Root, StyledRoot);
  const [ScrollContainer, scrollContainerProps] = getOverrides(overrides.ScrollContainer, StyledScrollContainer);
  const [Heading, headingProps] = getOverrides(overrides.Heading, StyledHeading);
  const [Body, bodyProps] = getOverrides(overrides.Body, StyledBody);
  const [ButtonDock, buttonDockProps] = getOverrides(overrides.ButtonDock, DefaultButtonDock);
  const [DismissButton, dismissButtonProps] = getOverrides(overrides.DismissButton, DefaultDismissButton);
  const dialogRef = React.useRef(null);
  React.useEffect(() => {
    if (isOpen) {
      if (hasOverlay) {
        dialogRef.current.showModal();
      } else {
        dialogRef.current.show();
      }
    } else {
      dialogRef.current.close();
    }
  }, [isOpen, hasOverlay]);

  function handleOutsideClick(e) {
    if (!dialogRef.current.contains(e.target) || e.target.nodeName === 'DIALOG') {
      handleDismiss();
    }
  }

  function handleEscapeKey(e) {
    if (e.key === 'Escape') {
      handleDismiss();
    }
  }

  React.useEffect(() => {
    if (isOpen) {
      // No delay, just pushing it to the end of the call stack so that the
      // Dialog doesn't close immediately after opening via click event
      const timer = setTimeout(() => {
        document.addEventListener('click', handleOutsideClick);
      }, 0);
      document.addEventListener('keydown', handleEscapeKey);
      return () => {
        clearTimeout(timer);
        document.removeEventListener('click', handleOutsideClick);
        document.removeEventListener('keydown', handleEscapeKey);
      };
    } else {
      document.removeEventListener('click', handleOutsideClick);
      document.removeEventListener('keydown', handleEscapeKey);
    }
  }, [isOpen]);
  return /*#__PURE__*/React.createElement(Root, _extends({
    ref: dialogRef,
    $isOpen: isOpen,
    $size: size,
    $placement: placement
  }, rootProps), handleDismiss && showDismissButton && /*#__PURE__*/React.createElement(DismissButton, _extends({
    onClick: () => handleDismiss()
  }, dismissButtonProps)), /*#__PURE__*/React.createElement(ScrollContainer, _extends({}, scrollContainerProps, {
    tabIndex: 0
  }), renderArtwork(artwork), /*#__PURE__*/React.createElement(Heading, _extends({
    $numHeadingLines: numHeadingLines
  }, headingProps), heading), /*#__PURE__*/React.createElement(Body, bodyProps, children)), buttonDock && /*#__PURE__*/React.createElement(ButtonDock, _extends({}, buttonDock, buttonDockProps)));
};

export default Dialog;