var _DIALOG_WIDTHS;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*
Copyright (c) Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import { styled } from '../styles';
import { SIZE, PLACEMENT } from './constants';

var getPlacementStyles = function getPlacementStyles(placement, gutter) {
  var defaultStyles = {
    top: 'auto',
    right: 'auto',
    bottom: 'auto',
    left: 'auto'
  };

  switch (placement) {
    case PLACEMENT.topLeft:
      return _objectSpread(_objectSpread({}, defaultStyles), {}, {
        top: gutter,
        left: gutter
      });

    case PLACEMENT.topCenter:
      return _objectSpread(_objectSpread({}, defaultStyles), {}, {
        top: gutter,
        left: '50%',
        transform: 'translateX(-50%)'
      });

    case PLACEMENT.topRight:
      return _objectSpread(_objectSpread({}, defaultStyles), {}, {
        top: gutter,
        right: gutter
      });

    case PLACEMENT.bottomLeft:
      return _objectSpread(_objectSpread({}, defaultStyles), {}, {
        bottom: gutter,
        left: gutter
      });

    case PLACEMENT.bottomCenter:
      return _objectSpread(_objectSpread({}, defaultStyles), {}, {
        bottom: gutter,
        left: '50%',
        transform: 'translateX(-50%)'
      });

    case PLACEMENT.bottomRight:
      return _objectSpread(_objectSpread({}, defaultStyles), {}, {
        bottom: gutter,
        right: gutter
      });

    case PLACEMENT.center:
      return _objectSpread(_objectSpread({}, defaultStyles), {}, {
        top: '50%',
        left: '50%',
        transform: 'translate(-50%, -50%)'
      });

    default:
      return defaultStyles;
  }
};

var DIALOG_WIDTHS = (_DIALOG_WIDTHS = {}, _defineProperty(_DIALOG_WIDTHS, SIZE.xSmall, '480px'), _defineProperty(_DIALOG_WIDTHS, SIZE.small, '640px'), _defineProperty(_DIALOG_WIDTHS, SIZE.medium, '800px'), _defineProperty(_DIALOG_WIDTHS, SIZE.large, '100%'), _DIALOG_WIDTHS);
export var StyledRoot = styled('dialog', function (_ref) {
  var $theme = _ref.$theme,
      $size = _ref.$size,
      _ref$$placement = _ref.$placement,
      $placement = _ref$$placement === void 0 ? PLACEMENT.center : _ref$$placement,
      $isOpen = _ref.$isOpen;
  var narrowViewportGutter = '16px';
  var wideViewportGutter = '40px';
  return _objectSpread(_objectSpread({
    position: 'fixed',
    maxHeight: "calc(100vh - 2 * ".concat(wideViewportGutter, ")"),
    maxWidth: "calc(100% - 2 * ".concat(wideViewportGutter, ")"),
    borderRadius: $theme.borders.radius500,
    boxShadow: $theme.lighting.shallowBelow,
    backgroundColor: $theme.colors.backgroundPrimary,
    color: $theme.colors.contentPrimary,
    overflow: 'hidden',
    border: 'none',
    width: DIALOG_WIDTHS[$size]
  }, getPlacementStyles($placement, wideViewportGutter)), {}, {
    '@media (max-width: 599px)': _objectSpread({
      width: "calc(100% - 2 * ".concat(narrowViewportGutter, ")")
    }, getPlacementStyles(PLACEMENT.bottomCenter, narrowViewportGutter)),
    '::backdrop': {
      backgroundColor: $theme.colors.backgroundOverlay
    },
    // Dialog style resets
    marginTop: '0px',
    marginRight: '0px',
    marginBottom: '0px',
    marginLeft: '0px',
    paddingTop: '0px',
    paddingRight: '0px',
    paddingBottom: '0px',
    paddingLeft: '0px'
  }, $isOpen ? {
    display: 'flex',
    flexDirection: 'column',
    alignItems: 'center'
  } : {});
});
StyledRoot.displayName = "StyledRoot";
StyledRoot.displayName = 'StyledRoot';
export var StyledScrollContainer = styled('div', function () {
  return {
    flex: 1,
    overflowY: 'auto',
    position: 'relative',
    width: '100%'
  };
});
StyledScrollContainer.displayName = "StyledScrollContainer";

function getLineWrapStyle(numHeadingLines) {
  if (numHeadingLines === 1) {
    return {
      overflow: 'hidden',
      whiteSpace: 'nowrap',
      textOverflow: 'ellipsis'
    };
  }

  return {
    overflow: 'hidden',
    display: '-webkit-box',
    WebkitLineClamp: "".concat(numHeadingLines),
    WebkitBoxOrient: 'vertical'
  };
}

export var StyledHeading = styled('div', // @ts-ignore-next-line - TODO: StyledObject does not support whiteSpace property?
function (_ref2) {
  var $theme = _ref2.$theme,
      _ref2$$numHeadingLine = _ref2.$numHeadingLines,
      $numHeadingLines = _ref2$$numHeadingLine === void 0 ? 2 : _ref2$$numHeadingLine;
  return _objectSpread(_objectSpread({
    position: 'sticky',
    top: 0,
    paddingTop: $theme.sizing.scale800,
    paddingLeft: $theme.sizing.scale800,
    paddingRight: $theme.sizing.scale800,
    '@media (max-width: 599px)': {
      paddingLeft: $theme.sizing.scale600,
      paddingRight: $theme.sizing.scale600
    },
    backgroundColor: $theme.colors.backgroundPrimary
  }, getLineWrapStyle($numHeadingLines)), $theme.typography.HeadingMedium);
});
StyledHeading.displayName = "StyledHeading";
StyledHeading.displayName = 'StyledHeading';
export var StyledBody = styled('div', function (_ref3) {
  var $theme = _ref3.$theme;
  return _objectSpread({
    marginTop: $theme.sizing.scale300,
    marginBottom: $theme.sizing.scale800,
    paddingLeft: $theme.sizing.scale800,
    paddingRight: $theme.sizing.scale800,
    '@media (max-width: 599px)': {
      paddingLeft: $theme.sizing.scale600,
      paddingRight: $theme.sizing.scale600
    }
  }, $theme.typography.ParagraphLarge);
});
StyledBody.displayName = "StyledBody";
StyledBody.displayName = 'StyledBody';